pub struct SessionIpForwardingConfig {
pub use_target_allow_list: bool,
pub target_allow_list: HashSet<SocketAddr>,
pub tcp_target_retry_delay: Duration,
pub max_tcp_target_retries: u32,
pub default_entry_listen_host: SocketAddr,
pub udp_rx_parallelism: Option<NonZeroUsize>,
}Expand description
Configuration of the Exit node (see HoprServerIpForwardingReactor)
and the Entry node.
Fields
use_target_allow_list: boolControls whether allowlisting should be done via target_allow_list.
If set to false, the node will act as an Exit node for any target.
Defaults to true.
target_allow_list: HashSet<SocketAddr>Enforces only the given target addresses (after DNS resolution).
This is used only if use_target_allow_list is set to true.
If left empty (and use_target_allow_list is true), the node will not act as an Exit node.
Defaults to empty.
tcp_target_retry_delay: DurationDelay between retries in seconds to reach a TCP target.
Defaults to 2 seconds.
max_tcp_target_retries: u32Maximum number of retries to reach a TCP target before giving up.
Default is 10.
default_entry_listen_host: SocketAddrSpecifies the default listen_host for Session listening sockets
at an Entry node.
udp_rx_parallelism: Option<NonZeroUsize>Number of parallel UDP receiver tasks per exit session.
None (default) lets the implementation choose automatically.